@@ -487,7 +487,8 @@ class Netgear(object):
         _LOGGER.debug("Allow block device")
         if self.config_started:
             _LOGGER.error("Inconsistant configuration state, configuration already started")
-            return False
+            if not self.config_finish():
+                return False
 
         if not self.config_start():
             _LOGGER.error("Could not start configuration")
@@ -524,7 +525,8 @@ class Netgear(object):
         _LOGGER.debug("reboot")
         if self.config_started:
             _LOGGER.error("Inconsistant configuration state, configuration already started")
-            return False
+            if not self.config_finish():
+                return False
 
         if not self.config_start():
             _LOGGER.error("Could not start configuration")
@@ -539,8 +541,17 @@ class Netgear(object):
             _LOGGER.error("Could not successfully call reboot")
             return False
 
+        self.config_started = False
+
         return True
 
+    def _post_request(self, headers, message):
+        """Post the API request to the router."""
+        return requests.post(
+            self.soap_url, headers=headers, data=message,
+            timeout=30, verify=False
+        )
+
     def _make_request(
         self,
         service,
@@ -574,10 +585,7 @@ class Netgear(object):
 
         try:
             try:
-                response = requests.post(
-                    self.soap_url, headers=headers, data=message,
-                    timeout=30, verify=False
-                )
+                response = self._post_request(headers, message)
             except requests.exceptions.SSLError:
                 _LOGGER.debug("SSL error, thread as unauthorized response "
                               "and try again after re-login")
@@ -586,7 +594,7 @@ class Netgear(object):
 
             if need_auth and _is_unauthorized_response(response):
                 # let's discard the cookie because it probably expired (v2)
-                # or the IP-bound (?) session expired (v1)
+                # or the IP-bound session expired (v1)
                 self.cookie = None
 
                 _LOGGER.debug("Unauthorized response, "
@@ -597,19 +605,24 @@ class Netgear(object):
 
                 # reset headers with new cookie first and re-try
                 headers = self._get_headers(service, method, need_auth)
-                response = requests.post(self.soap_url, headers=headers,
-                                         data=message, timeout=30,
-                                         verify=False)
+                response = self._post_request(headers, message)
 
             success = _is_valid_response(response)
             if not success and not self._logging_in:
                 if _is_unauthorized_response(response):
                     _LOGGER.error("Unauthorized response, "
                                   "after seemingly successful re-login")
+                elif _is_service_unavailable_response(response):
+                    # try the request one more time
+                    response = self._post_request(headers, message)
+                    success = _is_valid_response(response)
+                    if not success:
+                        _LOGGER.error("503 Service Unavailable after retry, "
+                                      "the API may be overloaded.")
                 else:
-                    _LOGGER.error("Invalid response")
-                    _LOGGER.debug("%s\n%s\n%s", response.status_code,
-                                  str(response.headers), response.text)
+                    _LOGGER.error("Invalid response: %s\n%s\n%s",
+                                  response.status_code, str(response.headers),
+                                  response.text)
 
             return success, response
 
@@ -698,6 +711,11 @@ def _is_unauthorized_response(resp):
             "<ResponseCode>401</ResponseCode>" in resp.text)
 
 
+def _is_service_unavailable_response(resp):
+    return (resp.status_code == 503 or
+            "<ResponseCode>503</ResponseCode>" in resp.text)
+
+
 def _convert(value, to_type, default=None):
     """Convert value to to_type, returns default if fails."""
     try:
